# Introduction

<img src="assets/sketch_tk.png" alt="picture" width="800"/>

## Installation

```sh
pip install bluemath-tk
```

## Authors

Demo codes have been developed through a collaborative effort by members of the GeoOcean group at the University of Cantabria. For inquiries, please contact Fernando Méndez at mendezf@unican.es

## Project status

- UNDER DEVELOPMENT